package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.FlightPathsMapper;
import com.ruoyi.system.domain.FlightPaths;
import com.ruoyi.system.service.IFlightPathsService;

/**
 * 航线文件信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-07-25
 */
@Service
public class FlightPathsServiceImpl implements IFlightPathsService 
{
    @Autowired
    private FlightPathsMapper flightPathsMapper;

    /**
     * 查询航线文件信息
     * 
     * @param id 航线文件信息主键
     * @return 航线文件信息
     */
    @Override
    public FlightPaths selectFlightPathsById(Long id)
    {
        return flightPathsMapper.selectFlightPathsById(id);
    }

    /**
     * 查询航线文件信息列表
     * 
     * @param flightPaths 航线文件信息
     * @return 航线文件信息
     */
    @Override
    public List<FlightPaths> selectFlightPathsList(FlightPaths flightPaths)
    {
        return flightPathsMapper.selectFlightPathsList(flightPaths);
    }

    /**
     * 新增航线文件信息
     * 
     * @param flightPaths 航线文件信息
     * @return 结果
     */
    @Override
    public int insertFlightPaths(FlightPaths flightPaths)
    {
        return flightPathsMapper.insertFlightPaths(flightPaths);
    }

    /**
     * 修改航线文件信息
     * 
     * @param flightPaths 航线文件信息
     * @return 结果
     */
    @Override
    public int updateFlightPaths(FlightPaths flightPaths)
    {
        return flightPathsMapper.updateFlightPaths(flightPaths);
    }

    /**
     * 批量删除航线文件信息
     * 
     * @param ids 需要删除的航线文件信息主键
     * @return 结果
     */
    @Override
    public int deleteFlightPathsByIds(Long[] ids)
    {
        return flightPathsMapper.deleteFlightPathsByIds(ids);
    }

    @Override
    public List<FlightPaths> selectByCondition(FlightPaths flightPaths) {
        return flightPathsMapper.selectByCondition(flightPaths);
    }

    /**
     * 删除航线文件信息信息
     * 
     * @param id 航线文件信息主键
     * @return 结果
     */
    @Override
    public int deleteFlightPathsById(Long id)
    {
        return flightPathsMapper.deleteFlightPathsById(id);
    }
}
